import logging

from django.db import connection
from uwsgidecorators import spool

import hobo.multitenant.settings_loaders  # this will get imported via importlib but fail for some reason in a uwsgi job
from hobo.provisionning.utils import NotificationProcessing


def set_connection(domain):
    from hobo.multitenant.middleware import TenantMiddleware

    tenant = TenantMiddleware.get_tenant_by_hostname(domain)
    connection.set_tenant(tenant)


@spool(pass_arguments=True)
def provision(*args, **kwargs):
    try:
        set_connection(kwargs['domain'])
        NotificationProcessing.provision(
            object_type=kwargs['object_type'],
            issuer=kwargs['issuer'],
            action=kwargs['action'],
            data=kwargs['data'],
            full=kwargs['full'],
        )
    except Exception:
        # we need to catch every exceptions otherwise the task will be re scheduled for ever and ever
        logging.getLogger(__name__).exception('provisionning failed')
